pub struct StoneTierCollectionWeight {
pub tier: StoneTier,
pub weight: f64,
}Expand description
The rarity weight of one equipment-stone tier.
Weight prices only the PASSIVE collection value of a template. It changes nothing about the stone’s effect, its drop chance or its upgrade cost.
Fields
tier: StoneTierweight: f64Trait Implementations
Sourceimpl Clone for StoneTierCollectionWeight
impl Clone for StoneTierCollectionWeight
Sourcefn clone(&self) -> StoneTierCollectionWeight
fn clone(&self) -> StoneTierCollectionWeight
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StoneTierCollectionWeight
impl Debug for StoneTierCollectionWeight
Sourceimpl<'de> Deserialize<'de> for StoneTierCollectionWeight
impl<'de> Deserialize<'de> for StoneTierCollectionWeight
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StoneTierCollectionWeight
impl JsonSchema for StoneTierCollectionWeight
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for StoneTierCollectionWeight
impl Tsify for StoneTierCollectionWeight
const DECL: &'static str = "/**\n * The rarity weight of one equipment-stone tier.\n *\n * Weight prices only the PASSIVE collection value of a template. It changes\n * nothing about the stone\\\'s effect, its drop chance or its upgrade cost.\n */\nexport interface StoneTierCollectionWeight {\n tier: StoneTier;\n weight: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Copy for StoneTierCollectionWeight